package org.rcisoft.bus.storegoodslog.controller;


/*固定导入*/

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.bus.storegoodslog.entity.StoreGoodsLog;
import org.rcisoft.bus.storegoodslog.service.StoreGoodsLogService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;

/**
* Created by cy on 2024年5月29日 下午1:21:49.
*/
@RestController
@RequestMapping("/storegoodslog")
public class StoreGoodsLogController extends CyPaginationController<StoreGoodsLog> {


    @Autowired
    private StoreGoodsLogService storeGoodsLogServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsLog:add')")
    @CyOpeLogAnno(title = "system-商品记录表管理-新增商品记录表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加商品记录表", notes="添加商品记录表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid StoreGoodsLog storeGoodsLog, BindingResult bindingResult) {
        CyPersistModel data = storeGoodsLogServiceImpl.persist(storeGoodsLog);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
                storeGoodsLog);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsLog:delete')")
    @CyOpeLogAnno(title = "system-商品记录表管理-删除商品记录表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除商品记录表", notes="逻辑删除商品记录表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId, StoreGoodsLog storeGoodsLog) {
        storeGoodsLog.setBusinessId(businessId);
        CyPersistModel data = storeGoodsLogServiceImpl.removeLogical(storeGoodsLog);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsLog:delete')")
    @CyOpeLogAnno(title = "system-商品记录表管理-删除商品记录表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除商品记录表", notes="删除商品记录表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId, StoreGoodsLog storeGoodsLog) {
        storeGoodsLog.setBusinessId(businessId);
        CyPersistModel data = storeGoodsLogServiceImpl.remove(storeGoodsLog);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsLog:update')")
    @CyOpeLogAnno(title = "system-商品记录表管理-修改商品记录表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改商品记录表", notes="修改商品记录表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid StoreGoodsLog storeGoodsLog, BindingResult bindingResult) {
        storeGoodsLog.setBusinessId(businessId);
        CyPersistModel data = storeGoodsLogServiceImpl.merge(storeGoodsLog);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
                storeGoodsLog);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsLog:query')")
    @CyOpeLogAnno(title = "system-商品记录表管理-查询商品记录表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一商品记录表", notes="查询单一商品记录表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        storeGoodsLogServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsLog:list')")
    @CyOpeLogAnno(title = "system-商品记录表管理-查询商品记录表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询商品记录表集合", notes="查询商品记录表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(StoreGoodsLog storeGoodsLog) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            storeGoodsLogServiceImpl.findAll(storeGoodsLog));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsLog:list')")
    @CyOpeLogAnno(title = "system-商品记录表管理-查询商品记录表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询商品记录表集合", notes="分页查询商品记录表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(StoreGoodsLog storeGoodsLog) {
        storeGoodsLogServiceImpl.findAllByPagination(getPaginationUtility(), storeGoodsLog);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-商品记录表管理-查询商品记录表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出商品记录表信息", notes = "导出商品记录表信息")
    @GetMapping(value = "/export")
    public void outWmsGoodsLog(HttpServletResponse response, StoreGoodsLog storeGoodsLog, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="商品记录表信息.xls";break;
            case "1": excelName="商品记录表信息.xlsx";break;
            case "2": excelName="商品记录表信息.csv";break;
        }
        List<StoreGoodsLog> storeGoodsLogList = storeGoodsLogServiceImpl.export(storeGoodsLog);
        CyEpExcelUtil.exportExcel(storeGoodsLogList, "商品记录表信息", "商品记录表信息", StoreGoodsLog.class, excelName, response);
    }
}
