package org.rcisoft.bus.wmsgoodslog.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.bus.wmsgoodslog.dao.WmsGoodsLogRepository;
import org.rcisoft.bus.wmsgoodslog.entity.WmsGoodsLog;
import org.rcisoft.bus.wmsgoodslog.service.WmsGoodsLogService;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * Created by cy on 2024年5月29日 下午1:21:49.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class WmsGoodsLogServiceImpl extends ServiceImpl<WmsGoodsLogRepository, WmsGoodsLog> implements WmsGoodsLogService {

    @Autowired
    private WmsGoodsLogService wmsGoodsLogServiceImpl;

    /**
     * 保存 商品记录表
     *
     * @param wmsGoodsLog
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(WmsGoodsLog wmsGoodsLog) {
        //增加操作
        int line = baseMapper.insert(wmsGoodsLog);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                wmsGoodsLog.getBusinessId() + "的商品记录表信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 商品记录表
     *
     * @param wmsGoodsLog
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(WmsGoodsLog wmsGoodsLog) {
        int line = baseMapper.realDelete(wmsGoodsLog);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                wmsGoodsLog.getBusinessId() + "的商品记录表信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 商品记录表
     *
     * @param wmsGoodsLog
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(WmsGoodsLog wmsGoodsLog) {
        wmsGoodsLog.setDeleted();
        int line = baseMapper.deleteById(wmsGoodsLog);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                wmsGoodsLog.getBusinessId() + "的商品记录表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 商品记录表
     *
     * @param wmsGoodsLog
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(WmsGoodsLog wmsGoodsLog) {
        int line = baseMapper.updateById(wmsGoodsLog);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + wmsGoodsLog.getBusinessId() + "的商品记录表信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 商品记录表
     *
     * @param id
     * @return
     */
    @Override
    public WmsGoodsLog findById(int id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 商品记录表
     *
     * @param wmsGoodsLog
     * @return
     */
    @Override
    public IPage<WmsGoodsLog> findAllByPagination(CyPageInfo<WmsGoodsLog> paginationUtility,
                                                  WmsGoodsLog wmsGoodsLog) {
        return baseMapper.queryWmsGoodsLogsPaged(paginationUtility, wmsGoodsLog);

    }

    /**
     * 查询list 商品记录表
     *
     * @param wmsGoodsLog
     * @return
     */
    @Override
    public List<WmsGoodsLog> findAll(WmsGoodsLog wmsGoodsLog) {
        return baseMapper.queryWmsGoodsLogs(wmsGoodsLog);

    }

    /**
     * 导出商品记录表
     *
     * @return
     */
    @Override
    public List<WmsGoodsLog> export(WmsGoodsLog wmsGoodsLog) {
        List<WmsGoodsLog> wmsGoodsLogList = baseMapper.queryWmsGoodsLogs(wmsGoodsLog);
        return wmsGoodsLogList;
    }
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel batchPersist(List<WmsGoodsLog> addLogList) {
        baseMapper.batchPersist(addLogList);
        return new CyPersistModel(1);
    }
}
