package org.rcisoft.bus.wmsgoodsprice.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.bus.wmsgoodsprice.dao.WmsGoodsPriceRepository;
import org.rcisoft.bus.wmsgoodsprice.entity.WmsGoodsPrice;
import org.rcisoft.bus.wmsgoodsprice.service.WmsGoodsPriceService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年12月12日 下午4:27:44.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class WmsGoodsPriceServiceImpl extends ServiceImpl<WmsGoodsPriceRepository,WmsGoodsPrice>  implements WmsGoodsPriceService {


    /**
    * 保存 价格管理表
    * @param wmsGoodsPrice
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(WmsGoodsPrice wmsGoodsPrice) {
        // 验证 goodsArtNumber 是否已存在
        WmsGoodsPrice existingRecord = baseMapper.selectByGoodsArtNumber(wmsGoodsPrice.getGoodsArtNumber());
        if (existingRecord != null) {
            throw new CyServiceException(1001, "货号已存在");
        }
        // 增加操作
        int line = baseMapper.insert(wmsGoodsPrice);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                wmsGoodsPrice.getBusinessId() + "的价格管理表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 价格管理表
    * @param wmsGoodsPrice
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(WmsGoodsPrice wmsGoodsPrice){
        int line = baseMapper.realDelete(wmsGoodsPrice);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            wmsGoodsPrice.getBusinessId()+"的价格管理表信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 价格管理表
    * @param wmsGoodsPrice
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(WmsGoodsPrice wmsGoodsPrice){
        wmsGoodsPrice.setDeleted();
        int line = baseMapper.deleteById(wmsGoodsPrice);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                wmsGoodsPrice.getBusinessId()+"的价格管理表信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 价格管理表
    * @param wmsGoodsPrice
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(WmsGoodsPrice wmsGoodsPrice){
        // 验证 goodsArtNumber 是否已存在
        WmsGoodsPrice existingRecord = baseMapper.selectByGoodsArtNumber(wmsGoodsPrice.getGoodsArtNumber());
        if (existingRecord != null && !existingRecord.getBusinessId().equals(wmsGoodsPrice.getBusinessId())) {
            throw new CyServiceException(1001, "货号已存在");
        }
        int line = baseMapper.updateById(wmsGoodsPrice);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ wmsGoodsPrice.getBusinessId()+"的价格管理表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 价格管理表
    * @param id
    * @return
    */
    @Override
    public WmsGoodsPrice findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 价格管理表
    * @param wmsGoodsPrice
    * @return
    */
    @Override
    public IPage<WmsGoodsPrice> findAllByPagination(CyPageInfo<WmsGoodsPrice> paginationUtility,
        WmsGoodsPrice wmsGoodsPrice){
        return baseMapper.queryWmsGoodsPricesPaged(paginationUtility,wmsGoodsPrice);

    }

    /**
    * 查询list 价格管理表
    * @param wmsGoodsPrice
    * @return
    */
    @Override
    public List<WmsGoodsPrice> findAll(WmsGoodsPrice wmsGoodsPrice){
        return baseMapper.queryWmsGoodsPrices(wmsGoodsPrice);

    }

    /**
    * 导出价格管理表
    * @return
    */
    @Override
    public List<WmsGoodsPrice> export(WmsGoodsPrice wmsGoodsPrice) {
        List<WmsGoodsPrice> wmsGoodsPriceList = baseMapper.queryWmsGoodsPrices(wmsGoodsPrice);

        return wmsGoodsPriceList;
    }

}
