package org.rcisoft.bus.wmsgoodsstock.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.CollectionUtils;
import org.rcisoft.bus.wmsgoods.entity.WmsGoods;
import org.rcisoft.bus.wmsgoodslog.dao.WmsGoodsLogRepository;
import org.rcisoft.bus.wmsgoodslog.entity.WmsGoodsLog;
import org.rcisoft.bus.wmsgoodsstock.dao.WmsGoodsStockRepository;
import org.rcisoft.bus.wmsgoodsstock.dto.WmsGoodsStockPageResultsDto;
import org.rcisoft.bus.wmsgoodsstock.entity.WmsGoodsStock;
import org.rcisoft.bus.wmsgoodsstock.service.WmsGoodsStockService;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * Created by cy on 2024年5月29日 下午1:21:49.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class WmsGoodsStockServiceImpl extends ServiceImpl<WmsGoodsStockRepository,WmsGoodsStock>  implements WmsGoodsStockService {

    @Autowired
    WmsGoodsLogRepository wmsGoodsLogRepository;

    /**
    * 保存 库存管理表
    * @param wmsGoodsStock
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(WmsGoodsStock wmsGoodsStock){
        //增加操作
        int line = baseMapper.insert(wmsGoodsStock);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            wmsGoodsStock.getBusinessId()+"的库存管理表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 库存管理表
    * @param wmsGoodsStock
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(WmsGoodsStock wmsGoodsStock){
        int line = baseMapper.realDelete(wmsGoodsStock);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            wmsGoodsStock.getBusinessId()+"的库存管理表信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 库存管理表
    * @param wmsGoodsStock
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(WmsGoodsStock wmsGoodsStock){
        wmsGoodsStock.setDeleted();
        int line = baseMapper.deleteById(wmsGoodsStock);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                wmsGoodsStock.getBusinessId()+"的库存管理表信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 库存管理表
    * @param wmsGoodsStock
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(WmsGoodsStock wmsGoodsStock){
        WmsGoodsStock wmsOrigin = baseMapper.selectById(wmsGoodsStock.getBusinessId());
        int line = baseMapper.updateById(wmsGoodsStock);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ wmsGoodsStock.getBusinessId()+"的库存管理表信息");
        WmsGoodsLog wmsGoodsLog = new WmsGoodsLog();
        wmsGoodsLog.setGoodsId(wmsGoodsStock.getBusinessId());
        wmsGoodsLog.setGoodsCounts(wmsOrigin.getGoodsCounts());
        wmsGoodsLog.setGoodsName(wmsOrigin.getGoodsName());
        wmsGoodsLog.setGoodsCode(wmsOrigin.getGoodsCode());
        wmsGoodsLog.setIoType("3");
        wmsGoodsLog.setUpdateCounts(wmsGoodsStock.getGoodsCounts());
        wmsGoodsLogRepository.insert(wmsGoodsLog);
        return new CyPersistModel(line);
    }
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel updateCounts(WmsGoodsStock wmsGoodsStock) {
        int line = baseMapper.updateById(wmsGoodsStock);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ wmsGoodsStock.getBusinessId()+"的库存管理表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 库存管理表
    * @param id
    * @return
    */
    @Override
    public WmsGoodsStock findById(int id){
        return baseMapper.selectById(id);
    }
    @Override
    public WmsGoodsStock findByIdOut(int id){
        return baseMapper.selectByIdOut(id);
    }
    /**
    * 分页查询 库存管理表
    * @param wmsGoodsStock
    * @return
    */
    @Override
    public IPage<WmsGoodsStockPageResultsDto> findAllByPagination(CyPageInfo<WmsGoodsStockPageResultsDto> paginationUtility,
                                                                  WmsGoodsStockPageResultsDto wmsGoodsStock){
        return baseMapper.queryWmsGoodsStocksPaged(paginationUtility,wmsGoodsStock);

    }

    /**
    * 查询list 库存管理表
    * @param wmsGoodsStock
    * @return
    */
    @Override
    public List<WmsGoodsStock> findAll(WmsGoodsStock wmsGoodsStock){
        return baseMapper.queryWmsGoodsStocks(wmsGoodsStock);

    }

    /**
    * 导出库存管理表
    * @return
    */
    @Override
    public List<WmsGoodsStock> export(WmsGoodsStock wmsGoodsStock) {
        List<WmsGoodsStock> wmsGoodsStockList = baseMapper.queryWmsGoodsStocks(wmsGoodsStock);
        return wmsGoodsStockList;
    }

    @Override
    public WmsGoodsStock queryWmsGoodsStock(WmsGoods wmsGoods) {
        WmsGoodsStock stock = new WmsGoodsStock();
        stock.setActualGoodsCode(wmsGoods.getGoodsCode());
        stock.setActualGtGoodsCounts(0);
        List<WmsGoodsStock> result = baseMapper.queryWmsGoodsStocks(stock);
        if(CollectionUtils.isEmpty(result) || result.size() > 1 || result.get(0).getGoodsCounts() < 1) {
            throw new CyServiceException(500, "商品不存在或库存不足！");
        }
        return result.get(0);
    }

}
